clc; clear; close all;
addpath utilties;
addpath model;
addpath model\Matlab ;
addpath img\reduced_scale

%% parameter settings
params.device_mode = 'gpu';          %   'gpu' or 'cpu'
params.dynamic_range = 11 ;
params.scale = 4;
params.max_value = 2^params.dynamic_range - 1 ;
params.sensor = 'WV2' ;
params.model = 'model\MatCaffe\baoming_deploy.prototxt';
params.weights = 'model\MatCaffe\_iter_3000.caffemodel';
params.RGB_index = [5 3 2];

%% loading data
load 'WV2_Reduced_Sample_1.mat';
% load 'WV2_Reduced_Sample_2.mat';
% load 'WV3_Reduced_Sample.mat';

%% preprocess
ms = double(ms) ;
pan = double(pan) ;
[ms_downsampled , pan_downsampled] = resize_images(ms , pan , params.scale, params.sensor) ;
LRMS = interp23tap(ms_downsampled , params.scale) ;
LRMS = LRMS / params.max_value ;
pan_downsampled = pan_downsampled / params.max_value ;

%% fusion process
proposed = proposed(LRMS, pan_downsampled, params);

%%  visualization
proposed_visualize = visualize(proposed , [0.01 , 0.99]) ;
LRMS_visualize = visualize(LRMS , [0.01 , 0.99]) ;
ms_visualize = visualize(ms , [0.01 , 0.99]) ;
pan_downsampled_visualize = visualize(pan_downsampled , [0.01 , 0.99]) ;
pan_visualize = visualize(pan , [0.01 , 0.99]) ;
ms_downsampled_visualize = visualize(ms_downsampled , [0.01 , 0.99]) ;

figure();
subplot(2,3,1); imshow(pan_visualize) ; title('Original PAN') ;
subplot(2,3,2); imshow(pan_downsampled_visualize) ; title('Downsampled PAN') ;
subplot(2,3,3); imshow(ms_downsampled_visualize(:,:,params.RGB_index)) ; title('Degraded MS') ;
subplot(2,3,4); imshow(LRMS_visualize(:,:,params.RGB_index)) ; title('Upsampled Degraded MS') ;
subplot(2,3,5); imshow(proposed_visualize(:,:,params.RGB_index)) ; title('Proposed Result') ;
subplot(2,3,6); imshow(ms_visualize(:,:,params.RGB_index)) ; title('Raw MS / Ground Truth') ;