function merged = fusion(model, LRMS, pan_downsampled)

%% loading parameters
load(model);
biases_conv1 = double(biases_conv1);
biases_conv2 = double(biases_conv2);
biases_conv3 = double(biases_conv3);
biases_conv4 = double(biases_conv4);
weights_conv1 = double(weights_conv1);
weights_conv2 = double(weights_conv2);
weights_conv3 = double(weights_conv3);
weights_conv4 = double(weights_conv4);
prelu1 = double(prelu1);
prelu2 = double(prelu2);
prelu3 = double(prelu3);
[conv1_channels ,conv1_patchsize2 ,conv1_filters] = size(weights_conv1);
conv1_patchsize = sqrt(conv1_patchsize2);
[conv2_channels ,conv2_patchsize2 ,conv2_filters] = size(weights_conv2);
conv2_patchsize = sqrt(conv2_patchsize2);
[conv3_channels ,conv3_patchsize2 ,conv3_filters] = size(weights_conv3);
conv3_patchsize = sqrt(conv3_patchsize2);
[conv4_channels ,conv4_patchsize2 ,conv4_filters] = size(weights_conv4);
conv4_patchsize = sqrt(conv4_patchsize2);
[hei, wid, ~] = size(LRMS);
input = cat(3, LRMS, pan_downsampled);

%%  1st convolutional layer
h1 = waitbar(0,'Operation strated');
conv1_data = zeros(hei, wid, conv1_filters);
for i = 1 : conv1_filters
    for j = 1 : conv1_channels
        conv1_subfilter = reshape(weights_conv1(j,:,i), conv1_patchsize, conv1_patchsize);
        conv1_data(:,:,i) = conv1_data(:,:,i) + imfilter(input(:,:,j), conv1_subfilter, 'same', 'replicate');
    end
    conv1_data(:,:,i) = prelu(conv1_data(:,:,i) + biases_conv1(i), prelu1(i));
end
waitbar(1/4,h1,'Operation procedure:1st layer is done');

%%  2nd convolutional layer
conv2_data = zeros(hei, wid, conv2_filters);
factor_2 = 2 ;
for i = 1 : conv2_filters
    for j = 1 : conv2_channels
        conv2_subfilter = reshape(weights_conv2(j,:,i), conv2_patchsize, conv2_patchsize);
        conv2_data(:,:,i) = conv2_data(:,:,i) + imfilter(conv1_data(:,:,j), dilated(conv2_subfilter, factor_2), 'same', 'replicate');
    end
    conv2_data(:,:,i) = prelu(conv2_data(:,:,i) + biases_conv2(i), prelu2(i));
end
waitbar(2/4,h1,'Operation procedure:2nd layer is done');

%%  3rd convolutional layer
conv3_data = zeros(hei, wid, conv3_filters);
factor_3 = 3 ;
for i = 1 : conv3_filters
    for j = 1 : conv3_channels
        conv3_subfilter = reshape(weights_conv3(j,:,i), conv3_patchsize, conv3_patchsize);
        conv3_data(:,:,i) = conv3_data(:,:,i) + imfilter(conv2_data(:,:,j), dilated(conv3_subfilter, factor_3), 'same', 'replicate');
    end
    conv3_data(:,:,i) = prelu(conv3_data(:,:,i) + biases_conv3(i), prelu3(i));
end
concat = cat(3, conv3_data, conv2_data, conv1_data);
waitbar(3/4,h1,'Operation procedure:3rd layer is done');

%%  4th convolutional layer
conv4_data = zeros(hei, wid, conv4_filters);
for i = 1 : conv4_filters
    for j = 1 : conv4_channels
        conv4_subfilter = reshape(weights_conv4(j,:,i), conv4_patchsize, conv4_patchsize);
        conv4_data(:,:,i) = conv4_data(:,:,i) + imfilter(concat(:,:,j), conv4_subfilter, 'same', 'replicate');
    end
end
merged = conv4_data + LRMS ;
waitbar(4/4,h1,'Operation procedure:4th layer is done');
close(h1)
